#!/bin/bash

#
# backup-asmdb.sh - Dump and encrypt all ASM Postgres DB contents, then 
#                   zip and generate a hash file
# 
# Called as part of appliance backup.
#
# INPUT: These environment variables must be set for this script to run.
#    PASSWORD
#        The encryption password provided by ASM server (either typed in or
#        taken from Backup Settings) is expected to already be set in the 
#        environment in $PASSWORD.
#
#    TAR_FILE_NAME
#        The name of the tar file to create is also expected to alread be set
#        in the environment in $TAR_FILE_NAME
#

#
# Set to exit immediately if any command fails
#
set -e

#
# Validate PASSWORD environment variable
#
if [ -z $PASSWORD ]; then
    echo "PASSWORD environment variable not set"
    exit 1
fi

#
# Validate TAR_FILE_NAME environment variable
#
if [ -z "$TAR_FILE_NAME" ]; then
    echo "TAR_FILE_NAME environment variable not set"
    exit 1
fi

#
# Set our base dir 
#
BACKUP_DIR=/var/tmp/backup
if [ ! -d "$BACKUP_DIR" ]; then
    echo "Backup directory $BACKUP_DIR not found"
    exit 1
fi

#
# Fetch all the db names to back up
#
DB_NAMES=$(psql -t -c "select datname from pg_database pgdb,pg_user pguser where pguser.usesysid = pgdb.datdba and pguser.usename not in ('postgres')" alcm orion)
#DB_INFO_LIST=$(psql -t -c "select usename, datname from pg_database pgdb,pg_user pguser where pguser.usesysid = pgdb.datdba and pguser.usename not in ('postgres')" alcm orion|tr -d '|' | tr -s ' ')

#
# Validate list of ASM DB names non null/empty
#
if [ -z "$DB_NAMES" ]; then
    echo "Fetch of ASM DB names and owners returned empty list"
    exit 1
fi

#
# Dump each DB in $DB_INFO_LIST to a file and then encrypt that file with $PASSWORD
#
for DB_NAME in $DB_NAMES; do
    DB_NAME=$(echo $DB_NAME | tr -d '[[:space:]]')
    DB_OWNER=$(psql -t -c "select usename from pg_database pgdb,pg_user pguser where pguser.usesysid = pgdb.datdba and pgdb.datname in ('$DB_NAME')" alcm orion | tr -d '[[:space:]]')
    BACKUP_FILE="${BACKUP_DIR}/${DB_NAME}.bk"

    # Dump the database to a file
    pg_dump -U "$DB_OWNER" "$DB_NAME" -F t -f "$BACKUP_FILE"

    # Encrypt the file
    gpg --batch -q --passphrase $PASSWORD -c "$BACKUP_FILE"
done

#
# Now tar up all the encrypted files AND the puppet dir previously
# created
#
cd $BACKUP_DIR

tar -cf "$TAR_FILE_NAME" *.bk.gpg puppet

#
# Zip the tar ball
#
gzip "$TAR_FILE_NAME"

ZIP_TAR_FILE_NAME=${TAR_FILE_NAME}.gz

#
# Create checksum file
#
md5sumResult=$(md5sum "$ZIP_TAR_FILE_NAME")

echo $md5sumResult > ${ZIP_TAR_FILE_NAME}.sum

#
# Remove dump files and encrypted dump files
#
rm ${BACKUP_DIR}/*.bk*

#
# Echo the fill zipped tar file name
#
echo "$ZIP_TAR_FILE_NAME"

echo "Successfully backed up ASM DB"

exit 0
